Learn R Programming

u5mr (version 0.1.1)

coeff_trussell_ki: Coefficients for the estimation of child mortality multipliers k(i)

Description

This is a dataset of coefficients used to estimate multipliers k(i) in the TRUSSELL version of the BRASS method, using Coale-Demeny mortality models.

Usage

data(coeff_trussell_ki)

Arguments

Format

A data frame

Details

The basic estimation equation for the Trussell method (equation 4.3) is

$$k(i) = a(i) + b(i) P(1)/P(2) + c(i) P(2)/P(3)$$

  • extracted from page 26, Table 4.

References

United Nations Population Studies (1990) Step-by-Step Guide to the Estimation of Child Mortality No.107:1-83 (United Nations)