Learn R Programming

u5mr (version 0.1.1)

coeff_trussell_ti: Coefficients for the estimation of the time reference t(i)

Description

This is a dataset of coefficients used to derive the time reference t(i), for values of q(x) in the TRUSSELL version of the BRASS method, using Coale-Demeny mortality models.

Usage

data(coeff_trussell_ti)

Arguments

Format

A data frame

Details

The basic estimation equation for the Trussell method (equation 4.3) is

$$t(i) = a(i) + b(i) P(1)/P(2) + c(i) P(2)/P(3)$$

The names of coefficients were changed from e, f, and g to a, b, and c.

  • extracted from page 27, Table 5.

References

United Nations Population Studies (1990) Step-by-Step Guide to the Estimation of Child Mortality No.107:1-83 (United Nations)