Learn R Programming

u5mr (version 0.1.1)

panama: Panama 1976

Description

The data gathered by a survey in Panama between August and October 1976 can be used to demonstrate the estimation of child mortality from summary birth histories using the Trussell version of the BRASS method and the Coale-Demeny model life tables coale_demeny_ltm.

Usage

data(panama)

Arguments

Format

A data frame

Details

  • extracted from Table49 on page 78.

References

United Nations (1983) Manual X: indirect techniques for demographic estimation. Population studies No. 81. New York: United Nations Department of International Economic and Social Affairs (United Nations)