Learn R Programming

u5mr (version 0.1.1)

u5mr_cohort: Estimating under-five mortality using Maternal age cohort-derived methods

Description

[Stable]

u5mr_cohort() uses the maternal age cohort-derived methods (MAC) through summary birth history information and maternal age (or time since first birth) to calculate the under-five mortality estimates.

Usage

u5mr_cohort(
  data,
  women = "women",
  child_born = "child_born",
  child_dead = "child_dead",
  agegrp = "agegrp",
  iso3 = "KHM",
  svy_year = 2010
)

Arguments

data

preprocessed data

women

total number of women

child_born

children ever born

child_dead

children dead

agegrp

age grouping or time since first birth

iso3

the iso3 code of the country from which the survey data come

svy_year

end of the survey

Value

data.frame

  • iso3 - total number of women

  • svy_year - total number of children ever born

  • agegrp - five-year age groups

  • ref_time - time between survey year and interpolated year

  • year - reference year

  • q5 - under-five mortality

Details

In this cohort-derived method, under-five mortality and reference time are estimated through summary birth history information from the mothers and her age or time since her first birth.

In case sample weights are available for the mothers, final variables should be multiplied by these weights before summarizing.

Computational Procedure

Two formulas were used to quantify MAC method:

\(5q0\) component

logit() = \(\beta\) + + \(\beta\) x logit( / ) + \(\beta\) x + \(\beta\) x PR1 + \(\beta\) x PR2 + \(\epsilon\)

where

i = 5-year maternal age group \(\epsilon\) (15-19, 20-24, ... , 45-49) j = country k = survey = total dead children from maternal age group i = total children ever born from maternal age group i PR1 = ratio of parity among maternal age group 15-19 and parity among maternal age group 20-24 PR2 = ratio of parity among maternal age group 20-24 and parity among maternal age group 25-29 = country-specific random effects

All coefficients vary by maternal age group, as indicated by i and the random effects also vary by country, as indicated by j.

Reference time component

= \(\beta\) + \(\beta\) x ( / ) + \(\beta\) x + \(\beta\) x PR1 + \(\beta\) x PR2 + \(\epsilon\)

References

Rajaratnam JK, Tran LN, Lopez AD, Murray CJL (2010) Measuring Under-Five Mortality: Validation of New Low-Cost Methods. PLOS Medicine 7(4): e1000253. (10.1371/journal.pmed.100025310.1371/journal.pmed.1000253)

Examples

Run this code
# NOT RUN {
## Example using fake survey data from Cambodia
data(cambodia)
camb <- u5mr_cohort(cambodia, women = "women", child_born = "child_born",
child_dead = "child_dead", agegrp = "agegrp", iso3 = "KHM", svy_year = 1234)

with(camb,
     plot(year, q5 * 1000, type = "b", pch = 19,
          col = "black", xlab = "Year", ylab = "U5MR per 1000 live births",
          main = paste0("Under-five mortality, q(5) in Bangladesh, estimated\n",
                       "using the maternal age cohort-derived method")))

# }

Run the code above in your browser using DataLab