k(i)This is a dataset of coefficients used to estimate multipliers k(i) in the TRUSSELL version of
the BRASS method, using Coale-Demeny mortality models.
data(coeff_trussell_ki)A data frame
The basic estimation equation for the Trussell method (equation 4.3) is
$$k(i) = a(i) + b(i) P(1)/P(2) + c(i) P(2)/P(3)$$
extracted from page 26, Table 4.
United Nations Population Studies (1990) Step-by-Step Guide to the Estimation of Child Mortality No.107:1-83 (United Nations)